@@ -16,5 +16,5 @@ test_that(desc="birthplace",{
 
 test_that(desc="Handle NA, interim and coordn in pin_birthplace",{
   suppressWarnings(expect_true(is.na(pin_birthplace(pin = as.pin(c("hejbaberiba","198501169885")))[1])))
-  expect_true(all(is.na(pin_birthplace(pin = c("19000625P816","190006859816")))))
+  suppressWarnings(expect_true(all(is.na(pin_birthplace(pin = c("19000625P816","190006859816"))))))
 })
